@@ -1,4 +1,5 @@
 import requests, json, os, traceback
+from datetime import datetime, timezone, date
 
 class ConsoleApi:
 
@@ -59,7 +60,6 @@ class ConsoleApi:
         return dados
 
     def grava_logs_local(self, conteudo):
-        from datetime import date
         try:
             arquivo = "logs_" + str(date.today()).replace('-','')+'.txt'
             dir_logs = os.getcwd() + "/arquivos/logs/"+arquivo
@@ -73,8 +73,6 @@ class ConsoleApi:
             print(error)
 
     def grava_arquivo_logs(self, json_error):
-        from datetime import date
-
         arquivo = "logError_" + str(date.today()).replace('-','')+'.json'
         dir_logs = os.getcwd() + "/arquivos/logs/"+arquivo
 
@@ -98,13 +96,20 @@ class ConsoleApi:
         with open(dir_logs, "w", encoding='utf_8_sig') as outfile:
             outfile.write(str(conteudo))
 
+    def start_tarefa(self,payload):
+        try:        
+            url = str(self.url)+"/tarefa/start/"
+
+            payload = json.dumps(payload)
+
+            response = self.post(url, payload)
+            return response
+        except Exception as erro:
+            self.grava_arquivo_logs(f"""{traceback.format_exc()}""")
+            return traceback.format_exc()
+
     def stop_automacao(self, tarefa_id, bo_status_code = 200, tx_resumo = 'Execução finalizada pela automação'):
-        import traceback
-        try:
-            from datetime import datetime, timezone
-            #from datetime import datetime as dt
-            #dt.now()
-        
+        try:        
             url = str(self.url)+"/tarefa/stop/"
 
             payload = {
